==> haskell-lifted-async-0.10.2.7-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-async
version:              0.10.2.7
visibility:           public
id:                   lifted-async-0.10.2.7-87xw9ol9qftFyElPFZWkJ2
key:                  lifted-async-0.10.2.7-87xw9ol9qftFyElPFZWkJ2
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2024 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  b8dbb33a90d32b1afc66d5ef67b5e505
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-async
hs-libraries:         HSlifted-async-0.10.2.7-87xw9ol9qftFyElPFZWkJ2
depends:
    async-2.2.5-EyV9emCuOIPGUIakwGPKTd base-4.17.2.1
    constraints-0.13.4-Cg8EtKdxyfaR6QV7hphYj
    lifted-base-0.2.3.12-GGucSQ8czOL5rdvlTsq43m
    monad-control-1.0.3.1-7R10NVdb48W9RXFDqz7pZ0
    transformers-base-0.4.6-9GQL5dr8RbxCW0vUqKz2fC

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.10.2.7-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-async
version:              0.10.2.7
visibility:           public
id:                   lifted-async-0.10.2.7-LHBeyt8pAG34ADSXp6iEhZ
key:                  lifted-async-0.10.2.7-LHBeyt8pAG34ADSXp6iEhZ
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2024 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  c8b22ededeec3a89d69e1e582b328a98
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-async
hs-libraries:         HSlifted-async-0.10.2.7-LHBeyt8pAG34ADSXp6iEhZ
depends:
    async-2.2.5-EyV9emCuOIPGUIakwGPKTd base-4.17.2.1
    constraints-0.13.4-Cg8EtKdxyfaR6QV7hphYj
    lifted-base-0.2.3.12-GGucSQ8czOL5rdvlTsq43m
    monad-control-1.0.3.1-7R10NVdb48W9RXFDqz7pZ0
    transformers-base-0.4.6-9GQL5dr8RbxCW0vUqKz2fC

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
